==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/PersistenceParser__24ArrayHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$ArrayHandlerCreator

// class file dependencies
// @dep_class a1fc7a5de8e8201d gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *);

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/PersistenceParser__24ArrayHandlerCreator.h <==
// class gnu.java.beans.decoder.PersistenceParser$ArrayHandlerCreator

// class file dependencies
// @dep_class c5188885a611e984 gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_
#define _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_gnu_java_beans_decoder_PersistenceParser$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object;

typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable;
typedef const struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method$_init$abe75c23fad35364(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_gnu_java_beans_decoder_PersistenceParser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object *_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method$createHandler$5a0dc6a0283274e0(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$method_info$createHandler$5a0dc6a0283274e0;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods {
	struct _jc_gnu_java_beans_decoder_AbstractElementHandler$object	*(*createHandler$5a0dc6a0283274e0)(_jc_env *, struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vmethods	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
};

// Vtype
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs {
	struct _jc_gnu_java_beans_decoder_PersistenceParser$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs {
    _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_refs	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$sub_nonrefs	gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$object {
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype	*vtype;
	_jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$vtype _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator$class_object;

#endif	/* _JC_gnu_java_beans_decoder_PersistenceParser__24ArrayHandlerCreator_H_ */
